@@ -6,6 +6,15 @@ import socket
 import sys
 import sysconfig
 
+# pytuple shortcut lambda:
+pytuple = lambda *attrs: tuple('__%s__' % str(atx) for atx in attrs)
+
+# Project base path:
+BASEPATH = sys.intern(
+           os.path.dirname(
+           os.path.dirname(
+           os.path.dirname(__file__))))
+
 # Possible names for builtin modules:
 BUILTINS = ('__builtins__', '__builtin__', 'builtins', 'builtin')
 
@@ -29,8 +38,8 @@ HOSTNAME = sys.intern(socket.gethostname())
 
 # The __name__ of a lambda function:
 lam = lambda: None
-LAMBDA = sys.intern(getattr(lam, '__qualname__',
-                    getattr(lam, '__name__', None)))
+λ = LAMBDA = sys.intern(getattr(lam, '__qualname__',
+                        getattr(lam, '__name__', None)))
 
 # N.B. this may or may not be a PY2/PY3 thing:
 MAXINT = getattr(sys, 'maxint',
@@ -77,7 +86,6 @@ else:
 TOKEN = sys.intern(' -')
 
 # Stuff we want to keep out of namespaces:
-pytuple = lambda *attrs: tuple('__%s__' % str(atx) for atx in attrs)
 VERBOTEN = pytuple('all', 'cached', 'loader', 'file', 'spec')
 VERBOTEN += BUILTINS
 VERBOTEN += ('Namespace', 'SimpleNamespace')
@@ -96,14 +104,20 @@ class NoDefault(object):
     def __new__(cls, *a, **k):
         return cls
 
-__all__ = ('BUILTINS',
+# Manually rename `pytuple(…)` per mechanism of “clu.exporting.Exporter”:
+pytuple.__lambda_name__ = λ
+pytuple.__qualname__ = pytuple.__name__ = 'pytuple'
+pytuple.__doc__ = "pytuple(*attrs) → turns ('do', 're', 'mi') into ('__do__', '__re__', '__mi__')"
+
+__all__ = ('BASEPATH',
+           'BUILTINS',
            'DEBUG',
            'DELETE_FLAG',
            'DYNAMIC_MODULE_PREFIX',
            'ENCODING',
            'FILE_ARGUMENT_NAMES',
            'HOSTNAME',
-           'LAMBDA',
+           'LAMBDA', 'λ',
            'MAXINT',
            'PATH',
            'PROJECT_NAME',
@@ -116,6 +130,35 @@ __all__ = ('BUILTINS',
            'VERBOTEN',
            'XDG_RUNTIME_BASE', 'XDG_RUNTIME_DIR',
                                'XDG_RUNTIME_MODE',
-           'NoDefault')
+           'pytuple', 'NoDefault')
 
-__dir__ = lambda: list(__all__)
\ No newline at end of file
+__dir__ = lambda: list(__all__)
+
+def print_all():
+    """ Print out all of the constant variables defined in consts.py """
+    # It’s not pretty – but actually it’s almost pretty, sort-of.
+    WIDTH = 125
+    
+    print('*' * WIDTH)
+    print("≠≠≠ CONSTS: (total %i)" % len(__all__))
+    print('*' * WIDTH)
+    
+    G = globals()
+    SEP = ",\n" + (" " * 30)
+    
+    printout = lambda name, value: print("» %25s : %s" % (name, value))
+    
+    for const_name in __all__:
+        if const_name.endswith('PATH') and os.pathsep in G[const_name]:
+            printout(const_name, G[const_name].replace(os.pathsep, SEP))
+        elif type(G[const_name]) is tuple:
+            printout(const_name, SEP.join("“%s”" % str(g) for g in G[const_name]))
+        elif type(G[const_name]) is str:
+            printout(const_name, "“%s”" % G[const_name])
+        else:
+            printout(const_name, G[const_name])
+    
+    print('*' * WIDTH)
+
+if __name__ == '__main__':
+    print_all()
\ No newline at end of file
