@@ -4,7 +4,7 @@ from __future__ import print_function
 from collections import Counter, OrderedDict
 from enum import Enum, EnumMeta, unique, _is_dunder as ispyname
 
-from .consts import PY3
+from .consts import PY3, pytuple
 
 class AutoType(object):
     
@@ -32,9 +32,15 @@ if PY3:
     long = int
 
 try:
-    from collections.abc import Mapping, MutableMapping, Hashable as HashableABC
+    from collections.abc import (Mapping, MutableMapping,
+                                 Hashable as HashableABC,
+                                 Sequence as SequenceABC,
+                                 Sized as SizedABC)
 except ImportError:
-    from collections import Mapping, MutableMapping, Hashable as HashableABC
+    from collections import (Mapping, MutableMapping,
+                             Hashable as HashableABC,
+                             Sequence as SequenceABC,
+                             Sized as SizedABC)
 
 try:
     from importlib.util import cache_from_source
@@ -58,14 +64,20 @@ except ImportError:
         from pathlib2 import Path
     except ImportError:
         Path = None
+try:
+    import numpy
+except (ImportError, SyntaxError):
+    numpy = None
 
 __all__ = ('Counter', 'OrderedDict',
-           'Enum', 'EnumMeta', 'unique', 'ispyname',
+           'Enum', 'EnumMeta', 'unique',
+           'ispyname', 'pytuple',
            'AutoType', 'auto',
            'unicode', 'long',
-           'Mapping', 'MutableMapping', 'HashableABC',
+           'Mapping', 'MutableMapping',
+           'HashableABC', 'SequenceABC', 'SizedABC',
            'cache_from_source',
            'lru_cache',
-           'Path')
+           'Path', 'numpy')
 
 __dir__ = lambda: list(__all__)
\ No newline at end of file
