@@ -2,9 +2,14 @@
 from __future__ import print_function
 
 from predicates import haspyattr
+from exporting import Exporter
 
-# UTILITY FUNCTIONS: dictionary-merging
+exporter = Exporter()
+export = exporter.decorator()
 
+# DICT FUNCTIONS: dictionary-merging
+
+@export
 def merge_two(one, two, cls=dict):
     """ Merge two dictionaries into an instance of the specified class
         Based on this docopt example source: https://git.io/fjCZ6
@@ -15,6 +20,7 @@ def merge_two(one, two, cls=dict):
     merged = ((key, one.get(key, None) or two.get(key, None)) for key in keys)
     return cls(merged)
 
+@export
 def merge_as(*dicts, **overrides):
     """ Merge all dictionary arguments into a new instance of the specified class,
         passing all additional keyword arguments to the class constructor as overrides
@@ -27,6 +33,7 @@ def merge_as(*dicts, **overrides):
         merged = merge_two(merged, d, cls=cls)
     return merged
 
+@export
 def merge(*dicts, **overrides):
     """ Merge all dictionary arguments into a new `dict` instance, using any
         keyword arguments as item overrides in the final `dict` instance returned
@@ -35,8 +42,9 @@ def merge(*dicts, **overrides):
         raise NameError('Cannot override the `cls` value')
     return merge_as(*dicts, cls=dict, **overrides)
 
-# UTILITY STUFF: asdict(…)
+# DICT STUFF: asdict(…)
 
+@export
 def asdict(thing):
     """ asdict(thing) → returns either thing, thing.__dict__, or dict(thing) as necessary """
     if isinstance(thing, dict):
@@ -45,5 +53,5 @@ def asdict(thing):
         return thing.__dict__
     return dict(thing)
 
-__all__ = ('merge_two', 'merge_as', 'merge', 'asdict')
-__dir__ = lambda: list(__all__)
\ No newline at end of file
+# Assign the modules’ `__all__` and `__dir__` using the exporter:
+__all__, __dir__ = exporter.all_and_dir()
\ No newline at end of file
