@@ -22,6 +22,7 @@ from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
 
 from constants import DELETE_FLAG, ENCODING, PATH
 from constants import lru_cache
+from constants import ExecutionError, FilesystemError
 from predicates import attr, allattrs
 from sanitizer import utf8_encode
 from typology import ispath, isvalidpath
@@ -45,18 +46,10 @@ __dir__ = lambda: list(__all__)
 DEFAULT_TIMEOUT = 60 # seconds
 DEFAULT_PREFIX = "yo-dogg-"
 
-class ExecutionError(Exception):
-    """ An error during the execution of a shell command """
-    pass
-
-class FilesystemError(Exception):
-    """ An error that occurred while mucking about with the filesystem """
-    pass
-
 def ensure_path_is_valid(pth):
     """ Raise an exception if we can’t write to the specified path """
     if not ispath(pth):
-        raise FilesystemError("Operand can’t be a path: %s" % pth)
+        raise FilesystemError("Operand must be a path type: %s" % pth)
     if os.path.exists(pth):
         if os.path.isdir(pth):
             raise FilesystemError("Can’t save over directory: %s" % pth)
@@ -234,7 +227,7 @@ def rm_rf(pth):
         pass
     return False
 
-def temporary(suffix=None, prefix=None, parent=None, **kwargs):
+def temporary(suffix='', prefix='', parent=None, **kwargs):
     """ Wrapper around `tempfile.mktemp()` that allows full overriding of the
         prefix and suffix by the caller -- that is to say, no random elements
         are used in the returned filename if both a prefix and a suffix are
@@ -246,6 +239,9 @@ def temporary(suffix=None, prefix=None, parent=None, **kwargs):
     """
     from tempfile import mktemp, gettempdir
     directory = os.fspath(kwargs.pop('dir', parent) or gettempdir())
+    if suffix:
+        if not suffix.startswith(os.extsep):
+            suffix = "%s%s" % (os.extsep, suffix)
     tempmade = mktemp(prefix=prefix, suffix=suffix, dir=directory)
     tempsplit = os.path.splitext(os.path.basename(tempmade))
     if not suffix:
@@ -342,8 +338,8 @@ def TemporaryNamedFile(tempth, mode='wb', buffer_size=-1, delete=True):
         
         Parameters
         ----------
-        tempth : str / bytes / descriptor / filename-ish
-            File name, path, or descriptor to open.
+        tempth : str / bytes  / filename-ish
+            File name, path, or filename-ish instance to open.
         mode : str / bytes, optional
             String-like symbolic explication of mode with which to open
             the file -- q.v. ``io.open(…)`` or ``__builtins__.open(…)``
