@@ -2,14 +2,17 @@
 from __future__ import print_function
 
 from .ansi import (print_separator, print_ansi, print_ansi_centered, highlight)
+from .ansi import (Text, Weight, Background, ANSIFormat)
 from .banners import (banners, is_python2_dead, print_python_banner, print_warning, banner)
-from .enums import (alias, AliasingEnumMeta)
+from .enums import (DUNDER, SUNDER, alias, AliasingEnumMeta, AliasingEnum)
 
 __all__ = ('print_separator',
            'print_ansi', 'print_ansi_centered',
            'highlight',
+           'Text', 'Weight', 'Background', 'ANSIFormat',
            'banners', 'is_python2_dead',
            'print_python_banner', 'print_warning', 'banner',
-           'alias', 'AliasingEnumMeta')
+           'DUNDER', 'SUNDER',
+           'alias', 'AliasingEnumMeta', 'AliasingEnum')
 
 __dir__ = lambda: list(__all__)
\ No newline at end of file
