@@ -7,7 +7,8 @@ import sys
 
 from constants import DYNAMIC_MODULE_PREFIX, PROJECT_NAME, VERBOTEN, cache_from_source
 from .namespace import SimpleNamespace, Namespace
-from naming import doctrim, dotpath_join, path_to_dotpath
+from exporting import doctrim
+from naming import dotpath_join, path_to_dotpath
 
 import types as thetypes
 types = Namespace()
@@ -36,9 +37,8 @@ setattr(types, '__cached__',      cache_from_source(__file__))
 setattr(types, '__package__',     os.path.splitext(
                                   os.path.basename(__file__))[0])
 
-def modulize(namespace, name,
-                        docs=None,
-                        path=None):
+def modulize(name, namespace, docs=None,
+                              path=None):
     """ Convert a dictionary mapping into a legit Python module """
     
     # Ensure a module with the given module name we received
@@ -104,5 +104,5 @@ def modulize(namespace, name,
     # Return our new module instance:
     return module
 
-__all__ = ('SimpleNamespace', 'Namespace', 'types', 'path_to_dotpath', 'modulize')
+__all__ = ('SimpleNamespace', 'Namespace', 'types', 'modulize')
 __dir__ = lambda: list(__all__)
\ No newline at end of file
