@@ -2,17 +2,6 @@
 from __future__ import print_function
 
 import pytest
-import array, decimal, os
-
-from clu.typology import (graceful_issubclass,
-                          ispathtype, ispath, isvalidpath,
-                          isnumber, isnumeric, isarray,
-                          isstring, isbytes,
-                          islambda,
-                          isfunction)
-
-from clu.predicates import attr
-from clu.typespace import SimpleNamespace
 
 class TestPredicates(object):
     
@@ -48,7 +37,7 @@ class TestPredicates(object):
     
     def test_slot_aware_attribute_checkers(self):
         """ » Checking “thing/class/slotted/dictish” lambdas from clu.predicates … """
-        from clu.typespace import Namespace
+        from clu.typespace import Namespace, SimpleNamespace
         from clu.predicates import (thing_has, class_has,
                                     isslotted, isdictish, isslotdicty)
         
@@ -316,6 +305,7 @@ class TestPredicates(object):
     def test_getattr_shortcuts(self):
         """ » Checking “getattr/getpyattr/getitem” shortcuts from clu.predicates … """
         from random import shuffle
+        from clu.constants import NoDefault
         from clu.predicates import (or_none, getpyattr, getitem,
                                     attr, pyattr, item,
                                     attr_search, pyattr_search, item_search)
@@ -331,9 +321,12 @@ class TestPredicates(object):
             assert or_none(d, 'get') is not None
             assert or_none(d, 'set') is None
             assert attr(d, 'set', 'delete', 'get') == or_none(d, 'get')
+            assert attr(d, 'set', 'delete', default=NoDefault) is NoDefault
             assert pyattr(d, 'bool', 'enter', 'exit', 'class') is dict
+            assert pyattr(d, 'bool', 'enter', 'exit', default=NoDefault) is NoDefault
             assert type(item(d, 'yo', 'i', 'you')) is str
             assert item(d, 'yo', 'i', 'you') in ("dogg", "heard", "like")
+            assert item(d, 'foo', 'bar', 'baz', default="DOGG") == "DOGG"
         
         assert getitem(dict0, 'yo') == "dogg"
         assert getitem(dict1, 'i') == "heard"
@@ -372,7 +365,7 @@ class TestPredicates(object):
     def test_ismergeable(self):
         """ » Checking “ismergeable” lambda from clu.predicates … """
         from clu.predicates import ismergeable
-        from clu.typespace import Namespace
+        from clu.typespace import Namespace, SimpleNamespace
         from collections import OrderedDict, defaultdict
         
         dic = { 'yo' : "dogg" }
@@ -500,6 +493,8 @@ class TestPredicates(object):
     
     def test_attr_accessor(self):
         """ » Checking “attr(•) accessor from clu.predicates …” """
+        from clu.predicates import attr
+        
         # plistlib on Python 2.x uses those ungainly `writePlistToString`
         # methods; on Python 3.x you have the more reasonable and expected
         # `dumps` and `loads` calls… thus, attr(…) will bridge the gap:
@@ -516,6 +511,16 @@ class TestPredicates(object):
     
     def test_boolean_predicates(self):
         """ » Checking basic isXXX(•) functions from clu.typology … """
+        import array, decimal, os
+        from clu.predicates import attr
+        from clu.typespace import SimpleNamespace
+        from clu.typology import (graceful_issubclass,
+                                  ispathtype, ispath, isvalidpath,
+                                  isnumber, isnumeric, isarray,
+                                  isstring, isbytes,
+                                  islambda,
+                                  isfunction)
+        
         assert graceful_issubclass(int, int)
         
         assert ispathtype(str)
@@ -551,7 +556,7 @@ class TestPredicates(object):
         assert islambda(lambda: None)
         assert islambda(attr)
         # assert not islambda(export)
-        assert not islambda(graceful_issubclass)
+        assert islambda(graceful_issubclass) # IT IS NOW DOGG
         assert isfunction(lambda: None)
         assert isfunction(attr)
         # assert isfunction(export)
@@ -560,6 +565,7 @@ class TestPredicates(object):
         assert isfunction(SimpleNamespace) # classes are callable!
     
     def test_numpy_predicates(self):
+        from clu.typology import isarray
         numpy = pytest.importorskip('numpy')
         assert isarray(numpy.ndarray)
         assert isarray(numpy.array([0, 1, 2]))
